@@ -19,49 +19,6 @@ _LOG = logging.getLogger("nowcasting_dataset")
 
 from nowcasting_dataset.consts import SAT_VARIABLE_NAMES
 
-# Means computed with
-# nwp_ds = NWPDataSource(...)
-# nwp_ds.open()
-# mean = nwp_ds.data.isel(init_time=slice(0, 10)).mean(
-#     dim=['step', 'x', 'init_time', 'y']).compute()
-SAT_MEAN = xr.DataArray(
-    data=[
-        93.23458,
-        131.71373,
-        843.7779,
-        736.6148,
-        771.1189,
-        589.66034,
-        862.29816,
-        927.69586,
-        90.70885,
-        107.58985,
-        618.4583,
-        532.47394,
-    ],
-    dims=["variable"],
-    coords={"variable": list(SAT_VARIABLE_NAMES)},
-).astype(np.float32)
-
-SAT_STD = xr.DataArray(
-    data=[
-        115.34247,
-        139.92636,
-        36.99538,
-        57.366386,
-        30.346825,
-        149.68007,
-        51.70631,
-        35.872967,
-        115.77212,
-        120.997154,
-        98.57828,
-        99.76469,
-    ],
-    dims=["variable"],
-    coords={"variable": list(SAT_VARIABLE_NAMES)},
-).astype(np.float32)
-
 
 @dataclass
 class SatelliteDataSource(ZarrDataSource):
@@ -75,7 +32,6 @@ class SatelliteDataSource(ZarrDataSource):
     channels: Optional[Iterable[str]] = SAT_VARIABLE_NAMES
     image_size_pixels: InitVar[int] = 128
     meters_per_pixel: InitVar[int] = 2_000
-    normalise: bool = True
 
     def __post_init__(self, image_size_pixels: int, meters_per_pixel: int):
         """ Post Init """
@@ -172,9 +128,6 @@ class SatelliteDataSource(ZarrDataSource):
     def _post_process_example(
         self, selected_data: xr.DataArray, t0_dt: pd.Timestamp
     ) -> xr.DataArray:
-        if self.normalise:
-            selected_data = selected_data - SAT_MEAN
-            selected_data = selected_data / SAT_STD
 
         selected_data.data = selected_data.data.astype(np.float32)
 
